@@ -12,7 +12,9 @@ several user-refined exceptions and validations.
 from pcapkit.utilities.compat import *  # pylint: disable=redefined-builtin
 from pcapkit.utilities.decorators import *
 from pcapkit.utilities.exceptions import *
+from pcapkit.utilities.logging import *
 from pcapkit.utilities.validations import *
 from pcapkit.utilities.warnings import *
 
-__all__ = ['seekset_ng', 'beholder_ng']
+__all__ = ['logger', 'warn', 'stacklevel',
+           'seekset_ng', 'beholder_ng']
